@@ -60,6 +60,29 @@ class StandardAPIView(BaseAPIView):
                 'error': str(e)
             })
             return Response(serializer.data, status=status.HTTP_400_BAD_REQUEST)
+    
+    def paginate_response_with_extra(self, request, data, extra):
+        try:
+            paginator = CustomPagination()
+            paginated_data = paginator.paginate_data(data, request)
+            response_data = {
+                'success': True,
+                'status': status.HTTP_200_OK,
+                'count': paginator.count,
+                'next': paginator.get_next_link(),
+                'previous': paginator.get_previous_link(),
+                'results': paginated_data,
+            }
+            response_data.update(extra)
+            serializer = APIResponseSerializer(response_data)
+            return Response(serializer.data)
+        except Exception as e:
+            serializer = APIResponseSerializer({
+                'success': False,
+                'status': status.HTTP_400_BAD_REQUEST,
+                'error': str(e)
+            })
+            return Response(serializer.data, status=status.HTTP_400_BAD_REQUEST)
 
 
 # ============= Demo Views ============= #
